@@ -1,12 +1,11 @@
-# -*- coding: utf-8 -*-
-
 import logging
+
 from ucloud.core.typesystem import schema, fields
 
 
 class ConfigSchema(schema.Schema):
     fields = {
-        "region": fields.Str(),
+        "region": fields.Str(required=True),
         "project_id": fields.Str(),
         "base_url": fields.Str(default="https://api.ucloud.cn"),
         "user_agent": fields.Str(),
@@ -14,14 +13,10 @@ class ConfigSchema(schema.Schema):
         "max_retries": fields.Int(default=3),
         "log_level": fields.Int(default=logging.INFO),
         "validate_request": fields.Bool(default=True),
-        "ssl_verify": fields.Bool(default=True),
-        "ssl_cacert": fields.Str(),
-        "ssl_cert": fields.Str(),
-        "ssl_key": fields.Str(),
     }
 
 
-class Config(object):
+class Config:
     """
     Config is the config of ucloud sdk, use for setting up
 
@@ -51,17 +46,14 @@ class Config(object):
 
     def __init__(
         self,
-        region=None,
-        project_id=None,
-        base_url="https://api.ucloud.cn",
-        user_agent=None,
-        timeout=30,
-        max_retries=3,
-        log_level=logging.INFO,
-        ssl_verify=True,
-        ssl_cacert=None,
-        ssl_cert=None,
-        ssl_key=None,
+        region: str,
+        project_id: str = None,
+        base_url: str = "https://api.ucloud.cn",
+        user_agent: str = None,
+        timeout: int = 30,
+        max_retries: int = 3,
+        log_level: int = logging.INFO,
+        validate_request: bool = True,
         **kwargs
     ):
         self.region = region
@@ -71,27 +63,12 @@ class Config(object):
         self.timeout = timeout
         self.max_retries = max_retries
         self.log_level = log_level
-        self.ssl_verify = ssl_verify
-        self.ssl_cacert = ssl_cacert
-        self.ssl_cert = ssl_cert
-        self.ssl_key = ssl_key
+        self.validate_request = validate_request
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, d: dict):
         parsed = ConfigSchema().dumps(d)
         return cls(**parsed)
 
-    def to_dict(self):
-        return {
-            "region": self.region,
-            "project_id": self.project_id,
-            "base_url": self.base_url,
-            "user_agent": self.user_agent,
-            "timeout": self.timeout,
-            "max_retries": self.max_retries,
-            "log_level": self.log_level,
-            "ssl_verify": self.ssl_verify,
-            "ssl_cacert": self.ssl_cacert,
-            "ssl_cert": self.ssl_cert,
-            "ssl_key": self.ssl_key,
-        }
+    def to_dict(self) -> dict:
+        return self.__dict__  # TODO: implement it.
