@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from ucloud.core.exc._exc import (
     UCloudException,
     ValidationException,
@@ -8,8 +6,8 @@ from ucloud.core.exc._exc import (
 )
 
 __all__ = [
-    "UCloudException",
-    "ValidationException",
-    "RetCodeException",
-    "RetryTimeoutException",
+    'UCloudException',
+    'ValidationException',
+    'RetCodeException',
+    'RetryTimeoutException',
 ]
